// GrayView.java
// By Ned Etcode
// Copyright 1996, 1997 Netscape Communications Corp.  All rights reserved.

import netscape.application.*;
import netscape.util.*;

/** The most common way to draw to the screen is to subclass View and
  * override the primitive drawing method, drawView(). In this simple example
  * we just fill our bounds with a solid shade of gray.
  */
public class GrayView extends View {
    int value;

    public GrayView(int x, int y, int width, int height) {
        super(x, y, width, height);
    }

    /** When our value changes, mark ourselves as dirty so we will get a
      * draw() message after processing the current Event.
      */
    public void setValue(int value) {
        this.value = value;
        setDirty(true);
    }

    public int value() {
        return value;
    }

    /** We override this to return false since we completely fill our bounds.
      * This will improve drawing performance since the View system knows
      * nothing beneath us will show through.
      */
    public boolean isTransparent() {
        return false;
    }

    public void drawView(Graphics g) {
        g.setColor(new Color(value, value, value));
        g.fillRect(0, 0, width(), height());
    }
}
